==> stove-0.0.1.tgz: stove/lib/controller.js <==
var Structr = require('sk/core/struct').Structr,
	net = require('psk/node/io/net'),
	URLRequest = net.Request,
	loadRequest = net.loadRequest;



exports.Controller = Structr({
	__construct: function()
	{
		//this.setCredentials('architectd','kpcofgs');
	},
	setCredentials: function (user, pass)
	{
		this.user(user);
		this.pass(pass);
	},
	'explicit user': 1,
	'explicit pass': 1, 
	login: function (callback)
	{
		this._get('validate/login', function(response)
		{
			callback(!!response.result);
		});
	},
	signup: function(callback)
	{
		this._post('signup', function(response)
		{
			callback(!!response.result);
		});
	},
	createApp: function(name, callback)
	{
		this._get('create/app/' + name, callback);	
	},
	removeApp: function(name, callback)
	{
		this._get('remove/app/' + name, callback);
	},
	getWhitelist: function(app, callback)
	{
		this._get('whitelist/' + app, callback);
	},
	whitelistAdd: function(url, app, callback)
	{
		this._get('whitelist/add/' + app, { url: escape(url) }, callback);
	},
	whitelistRemove: function(url, app, callback)
	{
		this._get('whitelist/remove/' + app, { url: escape(url) }, callback);
	},
	installNPMPackage: function(packageName, callback)
	{
		this._get('npm/install/' + packageName, callback);
	},
	startApp: function(name, callback)
	{
		this._get('start/app/' + name, function(response)
		{
			callback(!!response.result);
		});
	},
	stopApp: function(name, callback)
	{
		this._get('stop/app/' + name, function(response)
		{
			callback(!!response.result);
		});
	},
	getAvailablePlugins: function(callback)
	{
		this._get('available/plugins', function(response)
		{
			callback(response);
		});
	},
	getApps: function(callback)
	{
		this._get('list/apps', callback);
	},
	getAppPlugins: function(appName, callback)
	{
		this._get('list/' + appName + '/plugins', callback);
	},
	addPlugin: function(pluginName, appName, params, callback)
	{
		this._get('add/plugin/' + pluginName + '/' + appName, { params: encodeURIComponent(JSON.stringify(params || {})) }, function(response)
		{
			callback(!!response.result);
		});
	},
	removePlugin: function(pluginName, appName, callback)
	{
		this._get('remove/plugin/' + pluginName + '/' + appName, function(response)
		{
			callback(!!response.result);
		});
	},
	_get: function(uri, data, callback)
	{
		this._request(uri, 'GET', data, callback);
	},
	_post: function(uri, data, callback)
	{
		this._request(uri, 'POST', data, callback);
	},
	_request: function(uri, method, data, callback)
	{
		if(!callback)
		{
			callback = data;
			data = {};
		}
		
		var r = new URLRequest('http://api.spice.io/' + uri);
		r.data = data;
		r.method = method;
		r.setCredentials(this.user(),this.pass());
		
		loadRequest(r, function (response)
		{
			try {
				callback(JSON.parse(response));
			}catch(e)
			{
				callback({ error: 1 });
			}
		});
	}
});

==> stove-0.0.5.tgz: stove/lib/controller.js <==
var Structr = require('structr'),
	net = require('psk/node/io/net'),
	URLRequest = net.Request,
	loadRequest = net.loadRequest;



exports.Controller = Structr({
	__construct: function()
	{
		//this.setCredentials('architectd','kpcofgs');
	},
	setCredentials: function (user, pass)
	{
		this.user(user);
		this.pass(pass);
	},
	'explicit user': 1,
	'explicit pass': 1, 
	login: function (callback)
	{
		this._get('validate/login', function(response)
		{
			callback(!!response.result);
		});
	},
	signup: function(callback)
	{
		this._post('signup', function(response)
		{
			callback(!!response.result);
		});
	},
	createApp: function(name, callback)
	{
		this._get('create/app/' + name, callback);	
	},
	removeApp: function(name, callback)
	{
		this._get('remove/app/' + name, callback);
	},
	getWhitelist: function(app, callback)
	{
		this._get('whitelist/' + app, callback);
	},
	whitelistAdd: function(url, app, callback)
	{
		this._get('whitelist/add/' + app, { url: escape(url) }, callback);
	},
	whitelistRemove: function(url, app, callback)
	{
		this._get('whitelist/remove/' + app, { url: escape(url) }, callback);
	},
	installNPMPackage: function(packageName, callback)
	{
		this._get('npm/install/' + packageName, callback);
	},
	startApp: function(name, type, callback)
	{
		this._get('start/app/' + name + '/'+ (type || ''), function(response)
		{
			callback(!!response.result);
		});
	},
	stopApp: function(name, type, callback)
	{
		this._get('stop/app/' + name + '/' + (type || ''), function(response)
		{
			callback(!!response.result);
		});
	},
	getAvailablePlugins: function(callback)
	{
		this._get('available/plugins', function(response)
		{
			callback(response);
		});
	},
	getApps: function(callback)
	{
		this._get('list/apps', callback);
	},
	getAppPlugins: function(appName, callback)
	{
		this._get('list/' + appName + '/plugins', callback);
	},
	addPlugin: function(pluginName, appName, params, callback)
	{
		this._get('add/plugin/' + pluginName + '/' + appName, { params: encodeURIComponent(JSON.stringify(params || {})) }, function(response)
		{
			callback(!!response.result);
		});
	},
	removePlugin: function(pluginName, appName, callback)
	{
		this._get('remove/plugin/' + pluginName + '/' + appName, function(response)
		{
			callback(!!response.result);
		});
	},
	_get: function(uri, data, callback)
	{
		this._request(uri, 'GET', data, callback);
	},
	_post: function(uri, data, callback)
	{
		this._request(uri, 'POST', data, callback);
	},
	_request: function(uri, method, data, callback)
	{
		if(!callback)
		{
			callback = data;
			data = {};
		}
		
		var r = new URLRequest('http://api.spice.io/' + uri);
		r.data = data;
		r.method = method;
		r.setCredentials(this.user(),this.pass());
		
		loadRequest(r, function (response)
		{
			try {
				callback(JSON.parse(response));
			}catch(e)
			{
				callback({ error: 1 });
			}
		});
	}
});
